@@ -51,6 +51,17 @@ void Daemon::wake()
 	connect(ui_process, SIGNAL(finished(int, QProcess::ExitStatus)),
 		this, SLOT(uiFinished(int, QProcess::ExitStatus)));
 	ui_process->start(QCoreApplication::applicationFilePath(), QStringList("--wakeup"));
+
+	//save to history
+	QSettings settings;
+	QTime wake_at = settings.value("wake_at").toTime();
+
+	settings.beginGroup("history");
+	int num_used = settings.value(QString("%1/used").arg(wake_at.toString()), 0).toInt();
+	settings.setValue(QString("%1/used").arg(wake_at.toString()), num_used+1);
+	settings.endGroup();
+
+	settings.sync();
 }
 
 
