@@ -6,9 +6,9 @@
 class ModuleSettings : public QWidget {
 	Q_OBJECT
 public:
-	ModuleSettings(QWidget *parent): QWidget(parent) { };
-	void save() { };
+	ModuleSettings(QWidget *parent): QWidget(parent) { }
+	virtual ~ModuleSettings() { }
+	virtual void save() = 0;
 };
 
-
 #endif
